@@ -88,7 +88,14 @@ setMethod(
   "Filenames",
   signature = "ANY",
   definition = function(obj, allowMultiple) {
-    NULL
+    if (any(inherits(obj, "SpatVector"), inherits(obj, "SpatRaster"))) {
+      if (!requireNamespace("terra") && getOption("reproducible.useTerra", FALSE))
+        stop("Please install terra package")
+      fns <- terra::sources(obj)
+    } else {
+      fns <- NULL
+    }
+    fns
 })
 
 #' @export
